==> ldap-account-manager_7.7.orig.tar.bz2: ldap-account-manager-7.7/templates/lib/extra/ckeditor/plugins/table/lang/fi.js <==
/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'table', 'fi', {
	border: 'Rajan paksuus',
	caption: 'Otsikko',
	cell: {
		menu: 'Solu',
		insertBefore: 'Lisää solu eteen',
		insertAfter: 'Lisää solu perään',
		deleteCell: 'Poista solut',
		merge: 'Yhdistä solut',
		mergeRight: 'Yhdistä oikealla olevan kanssa',
		mergeDown: 'Yhdistä alla olevan kanssa',
		splitHorizontal: 'Jaa solu vaakasuunnassa',
		splitVertical: 'Jaa solu pystysuunnassa',
		title: 'Solun ominaisuudet',
		cellType: 'Solun tyyppi',
		rowSpan: 'Rivin jatkuvuus',
		colSpan: 'Solun jatkuvuus',
		wordWrap: 'Rivitys',
		hAlign: 'Horisontaali kohdistus',
		vAlign: 'Vertikaali kohdistus',
		alignBaseline: 'Alas (teksti)',
		bgColor: 'Taustan väri',
		borderColor: 'Reunan väri',
		data: 'Data',
		header: 'Ylätunniste',
		yes: 'Kyllä',
		no: 'Ei',
		invalidWidth: 'Solun leveyden täytyy olla numero.',
		invalidHeight: 'Solun korkeuden täytyy olla numero.',
		invalidRowSpan: 'Rivin jatkuvuuden täytyy olla kokonaisluku.',
		invalidColSpan: 'Solun jatkuvuuden täytyy olla kokonaisluku.',
		chooseColor: 'Valitse'
	},
	cellPad: 'Solujen sisennys',
	cellSpace: 'Solujen väli',
	column: {
		menu: 'Sarake',
		insertBefore: 'Lisää sarake vasemmalle',
		insertAfter: 'Lisää sarake oikealle',
		deleteColumn: 'Poista sarakkeet'
	},
	columns: 'Sarakkeet',
	deleteTable: 'Poista taulu',
	headers: 'Ylätunnisteet',
	headersBoth: 'Molemmat',
	headersColumn: 'Ensimmäinen sarake',
	headersNone: 'Ei',
	headersRow: 'Ensimmäinen rivi',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Reunan koon täytyy olla numero.',
	invalidCellPadding: 'Solujen sisennyksen täytyy olla numero.',
	invalidCellSpacing: 'Solujen välin täytyy olla numero.',
	invalidCols: 'Sarakkeiden määrän täytyy olla suurempi kuin 0.',
	invalidHeight: 'Taulun korkeuden täytyy olla numero.',
	invalidRows: 'Rivien määrän täytyy olla suurempi kuin 0.',
	invalidWidth: 'Taulun leveyden täytyy olla numero.',
	menu: 'Taulun ominaisuudet',
	row: {
		menu: 'Rivi',
		insertBefore: 'Lisää rivi yläpuolelle',
		insertAfter: 'Lisää rivi alapuolelle',
		deleteRow: 'Poista rivit'
	},
	rows: 'Rivit',
	summary: 'Yhteenveto',
	title: 'Taulun ominaisuudet',
	toolbar: 'Taulu',
	widthPc: 'prosenttia',
	widthPx: 'pikseliä',
	widthUnit: 'leveysyksikkö'
} );

==> ldap-account-manager_8.5.orig.tar.bz2: ldap-account-manager-8.5/templates/lib/extra/ckeditor/plugins/table/lang/fi.js <==
﻿/*
Copyright (c) 2003-2023, CKSource Holding sp. z o.o. All rights reserved.
CKEditor 4 LTS ("Long Term Support") is available under the terms of the Extended Support Model.
*/
CKEDITOR.plugins.setLang( 'table', 'fi', {
	border: 'Rajan paksuus',
	caption: 'Otsikko',
	cell: {
		menu: 'Solu',
		insertBefore: 'Lisää solu eteen',
		insertAfter: 'Lisää solu perään',
		deleteCell: 'Poista solut',
		merge: 'Yhdistä solut',
		mergeRight: 'Yhdistä oikealla olevan kanssa',
		mergeDown: 'Yhdistä alla olevan kanssa',
		splitHorizontal: 'Jaa solu vaakasuunnassa',
		splitVertical: 'Jaa solu pystysuunnassa',
		title: 'Solun ominaisuudet',
		cellType: 'Solun tyyppi',
		rowSpan: 'Rivin jatkuvuus',
		colSpan: 'Solun jatkuvuus',
		wordWrap: 'Rivitys',
		hAlign: 'Horisontaali kohdistus',
		vAlign: 'Vertikaali kohdistus',
		alignBaseline: 'Alas (teksti)',
		bgColor: 'Taustan väri',
		borderColor: 'Reunan väri',
		data: 'Data',
		header: 'Ylätunniste',
		columnHeader: 'Column Header', // MISSING
		rowHeader: 'Row Header', // MISSING
		yes: 'Kyllä',
		no: 'Ei',
		invalidWidth: 'Solun leveyden täytyy olla numero.',
		invalidHeight: 'Solun korkeuden täytyy olla numero.',
		invalidRowSpan: 'Rivin jatkuvuuden täytyy olla kokonaisluku.',
		invalidColSpan: 'Solun jatkuvuuden täytyy olla kokonaisluku.',
		chooseColor: 'Valitse'
	},
	cellPad: 'Solujen sisennys',
	cellSpace: 'Solujen väli',
	column: {
		menu: 'Sarake',
		insertBefore: 'Lisää sarake vasemmalle',
		insertAfter: 'Lisää sarake oikealle',
		deleteColumn: 'Poista sarakkeet'
	},
	columns: 'Sarakkeet',
	deleteTable: 'Poista taulu',
	headers: 'Ylätunnisteet',
	headersBoth: 'Molemmat',
	headersColumn: 'Ensimmäinen sarake',
	headersNone: 'Ei',
	headersRow: 'Ensimmäinen rivi',
	heightUnit: 'height unit', // MISSING
	invalidBorder: 'Reunan koon täytyy olla numero.',
	invalidCellPadding: 'Solujen sisennyksen täytyy olla numero.',
	invalidCellSpacing: 'Solujen välin täytyy olla numero.',
	invalidCols: 'Sarakkeiden määrän täytyy olla suurempi kuin 0.',
	invalidHeight: 'Taulun korkeuden täytyy olla numero.',
	invalidRows: 'Rivien määrän täytyy olla suurempi kuin 0.',
	invalidWidth: 'Taulun leveyden täytyy olla numero.',
	menu: 'Taulun ominaisuudet',
	row: {
		menu: 'Rivi',
		insertBefore: 'Lisää rivi yläpuolelle',
		insertAfter: 'Lisää rivi alapuolelle',
		deleteRow: 'Poista rivit'
	},
	rows: 'Rivit',
	summary: 'Yhteenveto',
	title: 'Taulun ominaisuudet',
	toolbar: 'Taulu',
	widthPc: 'prosenttia',
	widthPx: 'pikseliä',
	widthUnit: 'leveysyksikkö'
} );
